@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package HTML::Widget::Plugin;
 {
-  $HTML::Widget::Plugin::VERSION = '0.083';
+  $HTML::Widget::Plugin::VERSION = '0.100';
 }
 # ABSTRACT: base class for HTML widgets
 
@@ -64,47 +64,6 @@ sub provided_widgets {
     "something called abstract provided_widgets in HTML::Widget::Plugin";
 }
 
-sub import {
-  my ($class, $arg) = @_;
-  $arg ||= {};
-
-  my $target = $arg->{into} ||= caller(0);
-
-  my @widgets = $class->provided_widgets;
-
-  for my $widget (@widgets) {
-    my $install_to = $widget;
-    ($widget, $install_to) = @$widget if ref $widget;
-
-    # XXX: This is awkward because it checks ->can instead of provides_widget.
-    # This may be for the best since you don't want a widget called "new"
-    # -- rjbs, 2008-05-06
-    Carp::croak "$target can already provide widget '$widget'"
-      if $target->can($install_to);
-
-    {
-      no strict 'refs';
-      my $pw = \%{"$target\::_provided_widgets"};
-      $pw->{ $install_to } = 1;
-    }
-
-    Carp::croak
-      "$class claims to provide widget '$widget' but has no such method"
-      unless $class->can($widget);
-
-    Sub::Install::install_sub({
-      into => $target,
-      as   => $install_to,
-      code => sub {
-        my ($self, $given_arg) = @_;
-        my $arg = $class->rewrite_arg($given_arg);
-
-        $class->$widget($self, $arg);
-      }
-    });
-  }
-}
-
 1;
 
 __END__
@@ -117,7 +76,7 @@ HTML::Widget::Plugin - base class for HTML widgets
 
 =head1 VERSION
 
-version 0.083
+version 0.100
 
 =head1 DESCRIPTION
 
@@ -156,7 +115,7 @@ results are then returned.
 =head2 C< provided_widgets >
 
 This method should be implemented by any plugin.  It returns a list of method
-names which should be imported from the plugin into HTML::Widget::Factory.
+names which a factor should delegate to this plugin.
 
 =head1 AUTHOR
 
